package com.ruoyi.web.modules.trading.controller;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.modules.trading.domain.BizMarketDailyQuote;
import com.ruoyi.web.modules.trading.service.IBizMarketDailyQuoteService;

/**
 * 市场行情登记
 */
@RestController
@RequestMapping("/tradeMarket/marketQuote")
public class BizMarketDailyQuoteController extends BaseController
{
    @Autowired
    private IBizMarketDailyQuoteService bizMarketDailyQuoteService;

    @PreAuthorize("@ss.hasPermi('tradeMarket:marketQuote:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizMarketDailyQuote query)
    {
        startPage();
        List<BizMarketDailyQuote> list = bizMarketDailyQuoteService.selectBizMarketDailyQuoteList(query);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('tradeMarket:marketQuote:list')")
    @GetMapping("/tradeMarketOptions")
    public AjaxResult tradeMarketOptions()
    {
        return success(bizMarketDailyQuoteService.selectTradeMarketOptions());
    }

    @PreAuthorize("@ss.hasPermi('tradeMarket:marketQuote:query')")
    @GetMapping("/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bizMarketDailyQuoteService.selectBizMarketDailyQuoteById(id));
    }

    @PreAuthorize("@ss.hasPermi('tradeMarket:marketQuote:add')")
    @Log(title = "市场行情登记", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizMarketDailyQuote row)
    {
        row.setCreateBy(getUsername());
        return toAjax(bizMarketDailyQuoteService.insertBizMarketDailyQuote(row));
    }

    @PreAuthorize("@ss.hasPermi('tradeMarket:marketQuote:edit')")
    @Log(title = "市场行情登记", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizMarketDailyQuote row)
    {
        row.setUpdateBy(getUsername());
        return toAjax(bizMarketDailyQuoteService.updateBizMarketDailyQuote(row));
    }

    @PreAuthorize("@ss.hasPermi('tradeMarket:marketQuote:remove')")
    @Log(title = "市场行情登记", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bizMarketDailyQuoteService.deleteBizMarketDailyQuoteByIds(ids, getUsername()));
    }
}
